@@ -1,6 +1,9 @@
 #!/usr/bin/env python3
+from __future__ import annotations
+
 import localefix
 from comictaggerlib.main import ctmain
 
-if __name__ == '__main__':
+if __name__ == "__main__":
+    localefix.configure_locale()
     ctmain()
