@@ -1,46 +1,43 @@
 """A PyQt5 widget for editing the page list info"""
-
+#
 # Copyright 2012-2014 Anthony Beville
-
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from __future__ import annotations
 
 import logging
-from typing import Optional
 
 from PyQt5 import QtCore, QtGui, QtWidgets, uic
 
 from comicapi.comicarchive import ComicArchive, MetaDataStyle
-from comicapi.genericmetadata import PageType
+from comicapi.genericmetadata import ImageMetadata, PageType
 from comictaggerlib.coverimagewidget import CoverImageWidget
 from comictaggerlib.settings import ComicTaggerSettings
 
 logger = logging.getLogger(__name__)
 
 
-def item_move_events(widget):
+def item_move_events(widget: QtWidgets.QWidget) -> QtCore.pyqtBoundSignal:
     class Filter(QtCore.QObject):
 
         mysignal = QtCore.pyqtSignal(str)
 
-        def eventFilter(self, obj, event):
+        def eventFilter(self, obj: QtCore.QObject, event: QtCore.QEvent) -> bool:
 
             if obj == widget:
-                # print(event.type())
                 if event.type() == QtCore.QEvent.Type.ChildRemoved:
-                    # print("ChildRemoved")
                     self.mysignal.emit("finish")
                 if event.type() == QtCore.QEvent.Type.ChildAdded:
-                    # print("ChildAdded")
                     self.mysignal.emit("start")
                     return True
 
@@ -70,7 +67,7 @@ class PageListEditor(QtWidgets.QWidget):
         PageType.Deleted: "Deleted",
     }
 
-    def __init__(self, parent):
+    def __init__(self, parent: QtWidgets.QWidget) -> None:
         super().__init__(parent)
 
         uic.loadUi(ComicTaggerSettings.get_ui_file("pagelisteditor.ui"), self)
@@ -100,17 +97,17 @@ class PageListEditor(QtWidgets.QWidget):
         self.listWidget.itemSelectionChanged.connect(self.change_page)
         item_move_events(self.listWidget).connect(self.item_move_event)
         self.cbPageType.activated.connect(self.change_page_type)
-        self.chkDoublePage.toggled.connect(self.toggle_double_page)
+        self.chkDoublePage.clicked.connect(self.toggle_double_page)
         self.leBookmark.editingFinished.connect(self.save_bookmark)
         self.btnUp.clicked.connect(self.move_current_up)
         self.btnDown.clicked.connect(self.move_current_down)
         self.pre_move_row = -1
-        self.first_front_page = None
+        self.first_front_page: int | None = None
 
-        self.comic_archive: Optional[ComicArchive] = None
-        self.pages_list = []
+        self.comic_archive: ComicArchive | None = None
+        self.pages_list: list[ImageMetadata] = []
 
-    def reset_page(self):
+    def reset_page(self) -> None:
         self.pageWidget.clear()
         self.cbPageType.setDisabled(True)
         self.chkDoublePage.setDisabled(True)
@@ -118,49 +115,48 @@ class PageListEditor(QtWidgets.QWidget):
         self.comic_archive = None
         self.pages_list = []
 
-    def add_page_type_item(self, text, user_data, shortcut, show_shortcut=True):
+    def add_page_type_item(self, text: str, user_data: str, shortcut: str, show_shortcut: bool = True) -> None:
         if show_shortcut:
             text = text + " (" + shortcut + ")"
         self.cbPageType.addItem(text, user_data)
-        actionItem = QtWidgets.QAction(
-            shortcut, self, triggered=lambda: self.select_page_type_item(self.cbPageType.findData(user_data))
-        )
-        actionItem.setShortcut(shortcut)
-        self.addAction(actionItem)
+        action_item = QtWidgets.QAction(shortcut, self)
+        action_item.triggered.connect(lambda: self.select_page_type_item(self.cbPageType.findData(user_data)))
+        action_item.setShortcut(shortcut)
+        self.addAction(action_item)
 
-    def select_page_type_item(self, idx):
+    def select_page_type_item(self, idx: int) -> None:
         if self.cbPageType.isEnabled():
             self.cbPageType.setCurrentIndex(idx)
             self.change_page_type(idx)
 
-    def get_new_indexes(self, movement):
+    def get_new_indexes(self, movement: int) -> list[tuple[int, int]]:
         selection = self.listWidget.selectionModel().selectedRows()
         selection.sort(reverse=movement > 0)
-        newindexes = []
-        oldindexes = []
+        new_indexes: list[int] = []
+        old_indexes: list[int] = []
         for x in selection:
             current = x.row()
-            oldindexes.append(current)
+            old_indexes.append(current)
             if 0 <= current + movement <= self.listWidget.count() - 1:
-                if len(newindexes) < 1 or current + movement != newindexes[-1]:
+                if len(new_indexes) < 1 or current + movement != new_indexes[-1]:
                     current += movement
 
-            newindexes.append(current)
-        oldindexes.sort()
-        newindexes.sort()
-        return list(zip(newindexes, oldindexes))
+            new_indexes.append(current)
+        old_indexes.sort()
+        new_indexes.sort()
+        return list(zip(new_indexes, old_indexes))
 
-    def set_selection(self, indexes):
-        selection_ranges = []
+    def set_selection(self, indexes: list[tuple[int, int]]) -> list[tuple[int, int]]:
+        selection_ranges: list[tuple[int, int]] = []
         first = 0
-        for i, selection in enumerate(indexes):
+        for i, sel in enumerate(indexes):
             if i == 0:
-                first = selection[0]
+                first = sel[0]
                 continue
 
-            if selection != indexes[i - 1][0] + 1:
+            if sel[0] != indexes[i - 1][0] + 1:
                 selection_ranges.append((first, indexes[i - 1][0]))
-                first = selection[0]
+                first = sel[0]
 
         selection_ranges.append((first, indexes[-1][0]))
         selection = QtCore.QItemSelection()
@@ -173,7 +169,7 @@ class PageListEditor(QtWidgets.QWidget):
         self.listWidget.selectionModel().select(selection, QtCore.QItemSelectionModel.SelectionFlag.ClearAndSelect)
         return selection_ranges
 
-    def move_current_up(self):
+    def move_current_up(self) -> None:
         row = self.listWidget.currentRow()
         selection = self.get_new_indexes(-1)
         for sel in selection:
@@ -187,7 +183,7 @@ class PageListEditor(QtWidgets.QWidget):
         self.emit_front_cover_change()
         self.modified.emit()
 
-    def move_current_down(self):
+    def move_current_down(self) -> None:
         row = self.listWidget.currentRow()
         selection = self.get_new_indexes(1)
         selection.sort(reverse=True)
@@ -202,7 +198,7 @@ class PageListEditor(QtWidgets.QWidget):
         self.set_selection(selection)
         self.modified.emit()
 
-    def item_move_event(self, s):
+    def item_move_event(self, s: str) -> None:
         if s == "start":
             self.pre_move_row = self.listWidget.currentRow()
         if s == "finish":
@@ -211,14 +207,14 @@ class PageListEditor(QtWidgets.QWidget):
                 self.emit_front_cover_change()
                 self.modified.emit()
 
-    def change_page_type(self, i):
+    def change_page_type(self, i: int) -> None:
         new_type = self.cbPageType.itemData(i)
         if self.get_current_page_type() != new_type:
             self.set_current_page_type(new_type)
             self.emit_front_cover_change()
             self.modified.emit()
 
-    def change_page(self):
+    def change_page(self) -> None:
         row = self.listWidget.currentRow()
         pagetype = self.get_current_page_type()
 
@@ -237,27 +233,27 @@ class PageListEditor(QtWidgets.QWidget):
         if self.comic_archive is not None:
             self.pageWidget.set_archive(self.comic_archive, idx)
 
-    def get_first_front_cover(self):
+    def get_first_front_cover(self) -> int:
         front_cover = 0
         for i in range(self.listWidget.count()):
             item = self.listWidget.item(i)
-            page_dict = item.data(QtCore.Qt.ItemDataRole.UserRole)[0]  # .toPyObject()[0]
+            page_dict: ImageMetadata = item.data(QtCore.Qt.ItemDataRole.UserRole)[0]
             if "Type" in page_dict and page_dict["Type"] == PageType.FrontCover:
                 front_cover = int(page_dict["Image"])
                 break
         return front_cover
 
-    def get_current_page_type(self):
+    def get_current_page_type(self) -> str:
         row = self.listWidget.currentRow()
-        page_dict = self.listWidget.item(row).data(QtCore.Qt.ItemDataRole.UserRole)[0]  # .toPyObject()[0]
+        page_dict: ImageMetadata = self.listWidget.item(row).data(QtCore.Qt.ItemDataRole.UserRole)[0]
         if "Type" in page_dict:
             return page_dict["Type"]
 
         return ""
 
-    def set_current_page_type(self, t):
+    def set_current_page_type(self, t: str) -> None:
         row = self.listWidget.currentRow()
-        page_dict = self.listWidget.item(row).data(QtCore.Qt.ItemDataRole.UserRole)[0]  # .toPyObject()[0]
+        page_dict: ImageMetadata = self.listWidget.item(row).data(QtCore.Qt.ItemDataRole.UserRole)[0]
 
         if t == "":
             if "Type" in page_dict:
@@ -270,15 +266,19 @@ class PageListEditor(QtWidgets.QWidget):
         item.setData(QtCore.Qt.ItemDataRole.UserRole, (page_dict,))
         item.setText(self.list_entry_text(page_dict))
 
-    def toggle_double_page(self):
+    def toggle_double_page(self) -> None:
         row = self.listWidget.currentRow()
-        page_dict = self.listWidget.item(row).data(QtCore.Qt.UserRole)[0]
+        page_dict: ImageMetadata = self.listWidget.item(row).data(QtCore.Qt.UserRole)[0]
 
-        if self.sender().isChecked():
-            page_dict["DoublePage"] = str("true")
+        cbx = self.sender()
+
+        if isinstance(cbx, QtWidgets.QCheckBox) and cbx.isChecked():
+            if "DoublePage" not in page_dict:
+                page_dict["DoublePage"] = True
+                self.modified.emit()
         elif "DoublePage" in page_dict:
             del page_dict["DoublePage"]
-        self.modified.emit()
+            self.modified.emit()
 
         item = self.listWidget.item(row)
         # wrap the dict in a tuple to keep from being converted to QStrings
@@ -287,9 +287,9 @@ class PageListEditor(QtWidgets.QWidget):
 
         self.listWidget.setFocus()
 
-    def save_bookmark(self):
+    def save_bookmark(self) -> None:
         row = self.listWidget.currentRow()
-        page_dict = self.listWidget.item(row).data(QtCore.Qt.UserRole)[0]
+        page_dict: ImageMetadata = self.listWidget.item(row).data(QtCore.Qt.UserRole)[0]
 
         current_bookmark = ""
         if "Bookmark" in page_dict:
@@ -311,7 +311,7 @@ class PageListEditor(QtWidgets.QWidget):
 
         self.listWidget.setFocus()
 
-    def set_data(self, comic_archive: ComicArchive, pages_list: list):
+    def set_data(self, comic_archive: ComicArchive, pages_list: list[ImageMetadata]) -> None:
         self.comic_archive = comic_archive
         self.pages_list = pages_list
         if pages_list is not None and len(pages_list) > 0:
@@ -332,10 +332,10 @@ class PageListEditor(QtWidgets.QWidget):
         self.listWidget.itemSelectionChanged.connect(self.change_page)
         self.listWidget.setCurrentRow(0)
 
-    def list_entry_text(self, page_dict):
+    def list_entry_text(self, page_dict: ImageMetadata) -> str:
         text = str(int(page_dict["Image"]) + 1)
         if "Type" in page_dict:
-            if page_dict["Type"] in self.pageTypeNames.keys():
+            if page_dict["Type"] in self.pageTypeNames:
                 text += " (" + self.pageTypeNames[page_dict["Type"]] + ")"
             else:
                 text += " (Error: " + page_dict["Type"] + ")"
@@ -345,19 +345,19 @@ class PageListEditor(QtWidgets.QWidget):
             text += " " + "\U0001F516"
         return text
 
-    def get_page_list(self):
+    def get_page_list(self) -> list[ImageMetadata]:
         page_list = []
         for i in range(self.listWidget.count()):
             item = self.listWidget.item(i)
-            page_list.append(item.data(QtCore.Qt.ItemDataRole.UserRole)[0])  # .toPyObject()[0]
+            page_list.append(item.data(QtCore.Qt.ItemDataRole.UserRole)[0])
         return page_list
 
-    def emit_front_cover_change(self):
+    def emit_front_cover_change(self) -> None:
         if self.first_front_page != self.get_first_front_cover():
             self.first_front_page = self.get_first_front_cover()
             self.firstFrontCoverChanged.emit(self.first_front_page)
 
-    def set_metadata_style(self, data_style):
+    def set_metadata_style(self, data_style: int) -> None:
         # depending on the current data style, certain fields are disabled
 
         inactive_color = QtGui.QColor(255, 170, 150)
